package it.mokabyte.midp20.ws;
/**
* Classe che descrive un semplice esempio di accesso ad un WS attraverso
* le JSR-172 
*@author Massimo Carli
*@version 0.1(20/04/2005)
*/
import java.rmi.RemoteException;
import javax.xml.rpc.*;
import javax.microedition.midlet.*;
import javax.microedition.lcdui.*;
import it.mokabyte.midp20.ws.stub.*;


public class HiperLinkExtractorMIDlet extends MIDlet implements CommandListener{

  /*
  * Comando di uscita dall'applicazione
  */
  private final static Command exitCommand = new Command("esci",Command.EXIT,1);
  
  /*
  * Comando per l'accesso al servizio
  */
  private final static Command executeCommand = new Command("execute",Command.EXIT,1);  
  
  /*
  * Costanti che contengono le informazioni per l'accesso al servizio
  */
	private final static String SERVICE_URL			 = "http://www.atomic-x.com/xmlservices/HyperlinkExtractor.asmx";
	private final static String INPUT_PARAMETER 	= "http://www.mokabyte.it";


	/*
	* Riferimento al servizio (stub)
	*/
	private HyperlinkExtractorSoap_Stub serviceStub;

  /**
  * Costruttore di default
  */
  public HiperLinkExtractorMIDlet(){
  }

  /**
  * Metodo che viene invocato all'avvio della Midlet
  */
  public void startApp() {
  	// Inizializziamo lo stub per l'accesso al servizio
		serviceStub = new HyperlinkExtractorSoap_Stub();
		// Impostiamo i parametri per la connessione
		serviceStub._setProperty(Stub.ENDPOINT_ADDRESS_PROPERTY, SERVICE_URL);
		serviceStub._setProperty(Stub.SESSION_MAINTAIN_PROPERTY, new Boolean(true));		
		// Creazione interfaccia grafica
    Form displayable = new Form("HiperLinkExtractorMIDlet");
    displayable.addCommand(exitCommand);
    displayable.addCommand(executeCommand);
    displayable.setCommandListener(this);
    Display.getDisplay(this).setCurrent(displayable);
  }// fine 

  /**
  * Metodo che viene invocato alla pressione del tasto exit
  */
  public void commandAction(Command c, Displayable d){
    // Se viene premuto il pulsante di uscita si esce dall'applicazione
    if (c == exitCommand){
      destroyApp(true);
      notifyDestroyed();
    }else{
    	// Accesso al servizio all'interno di un processo opportuno come conviene sempre fare
    	// in questi casi
    	Thread seviceThread = new Thread(){
    		
    		public void run(){
    			// Chiamiamo il metodo di invocazione del servizio
    			executeService();
    		}// fine run	
    		
    		
    	};
    	// Avviamo il processo
    	seviceThread.start();
    }// fine
  }// fine

	/*
	* Accesso al servizio
	*/ 
  private void executeService(){
		try {
			// Accediamo al servizio passando il parametro definito in fase iniziale
			ArrayOfString returnArray = serviceStub.extractUrl(INPUT_PARAMETER);
			// Visualizziamo i risultati
			System.out.println("returnArray "+returnArray);
		} catch (Exception e) {
			// Errore in fase di accesso al servizio
			System.out.println("Errore "+e);
		}// fine
 	}// fine

  /**
  * Metodo invocato nel caso in cui la Midlet venga messa
  * in pausa
  */
  public void pauseApp() {
  }// fine 

  /**
  * Metodo invocato nel caso di chiusura della Midlet
  */
  public void destroyApp(boolean unconditional) {
  }// fine

}// fine Midlet

